#
# spec file for package mk-configure
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mk-configure
Version:        0.29.1
Release:        lp151.2.1
Summary:        Lightweight replacement for GNU autotools
License:        BSD-2-Clause and BSD-2-Clause and MIT and ISC
Group:          Development/Tools/Building
Url:            http://sourceforge.net/projects/mk-configure/
Source:         http://prdownloads.sf.net/%{name}/%{name}-%{version}.tar.gz
Source1:        mkcmake.macros
Source9:        mk-configure-rpmlintrc

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  bmake
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  groff
BuildRequires:  info
BuildRequires:  lua-devel
BuildRequires:  makedepend
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
Requires:       bmake
Recommends:     %{name}-doc
Provides:       %{name}-rpm-macros
BuildArch:      noarch

%description
mk-configure is a lightweight replacement for GNU autotools, written in
bmake (portable version of NetBSD make), POSIX shell and POSIX utilities.

%package doc
Summary:        MK-C' documentation
Group:          Documentation/Other
Requires:       %{name}

%description doc
Mk-configure package: examples and presentation.

%prep
%setup -q

%define env \
        unset MAKEFLAGS \
        export PREFIX=%{_prefix} \
        export MANDIR=%{_mandir}

# examples are built and tested either,
# let's keep a pristine copy
cp -al examples doc

%build
%{env}
bmake all

%install
%{env}
bmake install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_datadir}/doc/%{name}
# E: wrong-script-interpreter (Badness: 533)
chmod -x examples/hello_lua/foobar.in
chmod -x examples/hello_scripts/hello_world3.in
chmod -x examples/hello_subdirs/prog1/prog1.awk.in
# HACK vs. duplicates after %%doc macro.
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
cp -r examples %{buildroot}%{_docdir}/%{name}-doc
%fdupes -s %{buildroot}%{_docdir}/%{name}-doc
# rpm macros
install -m644 %{SOURCE1} -D %{buildroot}%{_sysconfdir}/rpm/macros.mkcmake

%check
unset MAKEFLAGS
env \
    LEXLIB=-lfl \
    NOSUBDIR='hello_lex hello_superfs hello_progs subprojects hello_lua hello_lua2 hello_lua3 hello_yacc hello_calc2 tools hello_dictd hello_libdeps' \
    bmake \
    test
bmake cleandir-examples
bmake cleandir-tests
# E: suse-filelist-forbidden-backup-file
rm -rf examples/*/*/*~

%files
%defattr(-,root,root)
%doc README doc/FAQ doc/LICENSE doc/NEWS doc/TODO
%{_bindir}/mkc*
%{_datadir}/mk-configure/
%{_datadir}/mkc-mk/
%{_mandir}/man1/*
%{_mandir}/man7/*
%config %{_sysconfdir}/rpm/macros.mkcmake

%files doc
%defattr(-,root,root)
%doc %{_docdir}/%{name}-doc/examples
%doc presentation/presentation.pdf

%changelog
* Sun May 29 2016 dap.darkness@gmail.com
- Added mkcmake.macros to provide rpm macros.
- Added mk-configure-rpmlintrc to skip some useless warnings.
- Don't override upstream's files permissions.
- Prevented files-duplicate warnings.
- Group was fixed.
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 0.29.1
  * FIX: features "progname", "warn", "err" and "fgetln" as well
    as _mkcfake.c file were added to the list of installed ones.
* Tue Dec  2 2014 dap.darkness@gmail.com
- 0.29.0 version:
  * New variables MKC_CHECK_CC_OPTS and MKC_CHECK_CXX_OPTS were
    introduced for checking C/C++ compiler's options;
  * Makefile.inc and Makefile.common are included after
    system variables are set, in particular CC and CXX;
  * CC_TYPE is now set in mk.init.mk;
  * Fixes for "err" and "warn" features.  Now verr(3), verrx(3),
    vwarn(3) and vwarnx(3) functions are detected correctly
    (the problem was seen on gcc-4.9/armv7);
  * Fix support for COMPATLIB.  Objects for "features" should not
    be generated outside compatibility library;
  * A number of fixes in regression tests: support for latest GCC,
    lib64 and lib/tri-ple-ts Linuxes;
  * mkc_check_custom:
  - new option -e for checking stderr for emptyness,
  - new option -b for printing yes/no instead of 1/0,
  - additional options to compiler are passed.
- `bmake cleandir-*` to clean examples dir after %%check.
* Sun Sep 14 2014 dap.darkness@gmail.com
- 0.28.0 version:
  * no upstream changelog.
- Disabled not Linux friendly hello_libdeps test.
* Sun Jun  1 2014 dap.darkness@gmail.com
- Imported from repoforge.
- SUSEficated.
* Wed Apr 17 2013 david@hrbac.cz
- new upstream release
* Sun Jul 22 2012 vle@gmx.net
- update to 0.23.0
* Sun Apr  8 2012 denis@fateyev.com
- Bump to 0.22.0
* Mon Jan  2 2012 vle@gmx.net
- adapted for repoforge
* Tue Dec 27 2011 mike@altlinux.org
- tweak examples so that they're built as well but packaged pristine
* Mon Dec 26 2011 mike@altlinux.org
- don't install just-built examples as docs
* Sat Dec 24 2011 mike@altlinux.org
- further spec cleanup
- check fixup (thx upstream)
- extended BR: properly
* Mon Nov 21 2011 mike@altlinux.org
- dropped MKCATPAGES (thx upstream)
* Mon Nov  7 2011 mike@altlinux.org
- 0.21.2
- minor spec cleanup
* Tue Jun 29 2010 lav@altlinux.ru
- add check section
* Fri Jun 25 2010 lav@altlinux.ru
- disable examples build
* Thu Jun 24 2010 lav@altlinux.ru
- fix install, disable lua test, enable all tests
- update buildreqs
* Fri Jun 18 2010 lav@altlinux.ru
- new version 0.16.0 (with rpmrb script)
* Tue Nov 17 2009 lav@altlinux.ru
- new version 0.12.0 (with rpmrb script)
* Wed Jul 29 2009 lav@altlinux.ru
- build for Sisyphus
* Thu Jul 23 2009 vle@gmx.net
- Not it depends on pkgsrc-mk-files, fixes and clean-ups
* Sun Jul 12 2009 lav@altlinux.ru
- initial build for ALT Linux Sisyphus
